==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: bg\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Линия"

, "Caller Id"
: "Идентификатор на обаждащият се"

, "Start"
: "Старт"

, "Connected"
: "Свързан"

, "Disconnected"
: "Несвързан (прекъсната връзка)"

, "Duration"
: "Продължителност"

, "Ringing"
: "Позвъняване"

, "Direction"
: "Направление"

, "Source"
: "Източник"

, "Destination"
: "Предназначение"

, "Phone"
: ""

, "Phones"
: "Телефони"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Номер"

, "Cancel"
: "Прекъсване"

, "Dial"
: "Набиране"

, "Error"
: ""

, "Not possible to dial."
: ""

, "Edit phone settings"
: "Редактирай условията на телефонниране"

, "Dial number"
: "Набран номер"

, "Initiate a new outgoing call"
: "Въведи ново изходящо обаждане"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Incoming call"
: "Влизащи позвънявания"

, "Outgoing call"
: "Излизащи позвънявания"

, "unknown number"
: "непознат номер"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Влизащи позвънявания"

, "Outgoing call"
: "Излизащи позвънявания"

, "unknown number"
: "непознат номер"

, "Phone"
: ""

, "Line"
: "Линия"

, "Number"
: "Номер"

, "Cancel"
: "Прекъсване"

, "Dial"
: "Набиране"

, "Error"
: ""

, "Not possible to dial."
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Edit phone settings"
: "Редактирай условията на телефонниране"

, "Dial number"
: "Набран номер"

, "Initiate a new outgoing call"
: "Въведи ново изходящо обаждане"

, "Phones"
: "Телефони"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Идентификатор на обаждащият се"

, "Start"
: "Старт"

, "Connected"
: "Свързан"

, "Disconnected"
: "Несвързан (прекъсната връзка)"

, "Duration"
: "Продължителност"

, "Ringing"
: "Позвъняване"

, "Direction"
: "Направление"

, "Source"
: "Източник"

, "Destination"
: "Предназначение"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
